@@ -1,16 +1,14 @@
-import importlib
 from decimal import Decimal
 
-import django
 from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.db import models
 from django.utils.encoding import force_str
+from django.utils.translation import gettext_lazy as _
 from jsonfield import JSONField
 
 from extra_settings import fields
 from extra_settings.cache import get_cached_setting, set_cached_setting
-from extra_settings.translation import gettext_lazy as _
 from extra_settings.utils import enforce_uppercase_setting, import_function
 
 
@@ -78,16 +76,19 @@ class Setting(models.Model):
                 value_type = item["type"]
                 value_type = value_type.replace("Setting.TYPE_", "").lower()
                 value = item["value"]
-            except KeyError:
+            except KeyError as error:
                 raise ValueError(
-                    "Setting 'defaults' item must contain 'name', 'type' and 'value' keys."
-                )
+                    "Setting 'defaults' item must contain "
+                    "'name', 'type' and 'value' keys."
+                ) from error
+            validator = item.get("validator", None)
             description = item.get("description", "")
             setting_obj, setting_created = cls.objects.get_or_create(
                 name=name,
                 defaults={
                     "value_type": value_type,
                     "description": description,
+                    "validator": validator,
                 },
             )
             if setting_created:
@@ -142,17 +143,34 @@ class Setting(models.Model):
         max_length=255,
         unique=True,
         verbose_name=_("Name"),
-        help_text="(e.g. SETTING_NAME)",
+        help_text=_("(e.g. SETTING_NAME)"),
     )
     value_type = models.CharField(
-        max_length=20, choices=TYPE_CHOICES, verbose_name=_("Type")
+        max_length=20,
+        choices=TYPE_CHOICES,
+        verbose_name=_(
+            "Type",
+        ),
+    )
+    description = models.TextField(
+        blank=True,
+        null=True,
+        verbose_name=_("Description"),
     )
-    description = models.TextField(blank=True, null=True, verbose_name=_("Description"))
 
-    value_bool = models.BooleanField(default=False, verbose_name=_("Value"))
-    value_date = models.DateField(blank=True, null=True, verbose_name=_("Value"))
+    value_bool = models.BooleanField(
+        default=False,
+        verbose_name=_("Value"),
+    )
+    value_date = models.DateField(
+        blank=True,
+        null=True,
+        verbose_name=_("Value"),
+    )
     value_datetime = models.DateTimeField(
-        blank=True, null=True, verbose_name=_("Value")
+        blank=True,
+        null=True,
+        verbose_name=_("Value"),
     )
     value_decimal = models.DecimalField(
         blank=True,
@@ -162,22 +180,57 @@ class Setting(models.Model):
         verbose_name=_("Value"),
     )
     value_duration = models.DurationField(
-        blank=True, null=True, verbose_name=_("Value")
+        blank=True,
+        null=True,
+        verbose_name=_("Value"),
+    )
+    value_email = models.EmailField(
+        blank=True,
+        verbose_name=_("Value"),
     )
-    value_email = models.EmailField(blank=True, verbose_name=_("Value"))
     value_file = models.FileField(
-        blank=True, upload_to=fields.upload_to_files, verbose_name=_("Value")
+        blank=True,
+        upload_to=fields.upload_to_files,
+        verbose_name=_("Value"),
+    )
+    value_float = models.FloatField(
+        blank=True,
+        default=0.0,
+        verbose_name=_("Value"),
     )
-    value_float = models.FloatField(blank=True, default=0.0, verbose_name=_("Value"))
     value_image = models.FileField(
-        blank=True, upload_to=fields.upload_to_images, verbose_name=_("Value")
+        blank=True,
+        upload_to=fields.upload_to_images,
+        verbose_name=_("Value"),
+    )
+    value_int = models.IntegerField(
+        blank=True,
+        default=0,
+        verbose_name=_("Value"),
+    )
+    value_json = JSONField(
+        blank=True,
+        default=dict,
+        verbose_name=_("Value"),
+    )
+    value_string = models.CharField(
+        blank=True,
+        max_length=255,
+        verbose_name=_("Value"),
+    )
+    value_text = models.TextField(
+        blank=True,
+        verbose_name=_("Value"),
+    )
+    value_time = models.TimeField(
+        blank=True,
+        null=True,
+        verbose_name=_("Value"),
+    )
+    value_url = models.URLField(
+        blank=True,
+        verbose_name=_("Value"),
     )
-    value_int = models.IntegerField(blank=True, default=0, verbose_name=_("Value"))
-    value_json = JSONField(blank=True, default=dict, verbose_name=_("Value"))
-    value_string = models.CharField(blank=True, max_length=255, verbose_name=_("Value"))
-    value_text = models.TextField(blank=True, verbose_name=_("Value"))
-    value_time = models.TimeField(blank=True, null=True, verbose_name=_("Value"))
-    value_url = models.URLField(blank=True, verbose_name=_("Value"))
     validator = models.CharField(
         blank=True,
         null=True,
@@ -203,7 +256,7 @@ class Setting(models.Model):
 
     def __init__(self, *args, **kwargs):
         value = kwargs.pop("value", None)
-        super(Setting, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         if value is not None:
             self.value = value
         self.name_initial = self.name
@@ -213,21 +266,21 @@ class Setting(models.Model):
             return
         validator_func = import_function(self.validator)
         if not validator_func:
-            raise ValueError(f"Invalid validator function path: '{self.validator}'")
+            raise ValueError(f"Invalid validator function path: {self.validator!r}")
         is_valid = validator_func(self.value)
         if not is_valid:
             raise ValidationError(
-                f"Invalid value for setting '{self.name}', "
-                f"{self.value} is not validated by '{self.validator}' validator."
+                f"Invalid value for setting {self.name!r}, "
+                f"{self.value!r} is not validated by {self.validator!r} validator."
             )
 
     def save(self, *args, **kwargs):
         if settings.EXTRA_SETTINGS_ENFORCE_UPPERCASE_SETTINGS:
             self.name = enforce_uppercase_setting(self.name)
-        super(Setting, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
     def clean(self):
-        super(Setting, self).clean()
+        super().clean()
         self.validate()
 
     class Meta:
